#ifndef IMPORT_EXPORT_JPEG_H
#define IMPORT_EXPORT_JPEG_H

/*
 * Performs JPEG compression and stores the result in a file.
 *
 * The image will be compressed using the data from image_chars,
 * which must be a flat array of size image_height x image_width.
 *
 * The resulting image will have dimensions image_height x image_width.
 *
 * The variable num_compontents defines the dimension of each pixel,
 * 1 for grayscale and 3 for RGB.
 *
 * The variable quality defines the level of compression, higher value
 * means better quality.
 */
extern void export_JPEG_file (const char* filename, const unsigned char* image_chars,
                              int image_height, int image_width,
                              int num_components, int quality);

/*
 * Reads a JPEG compressed image file.
 *
 * The image data will be stored in image_chars, this data
 * must be free'd after use.
 *
 * The image dimensions will be stored in image_height and
 * image_width.
 *
 * The pixel dimension will be stored in num_components,
 * 1 means grayscale and 3 means RGB.
 *
 * NOTE: After you are done with the image data it is important
 * to call free on the image_chars variable as it is implemented
 * with an underlying malloc call.
 */
extern void import_JPEG_file (const char* filename, unsigned char** image_chars,
                              int* image_height, int* image_width,
                              int* num_components);

#endif /* IMPORT_EXPORT_JPEG_H */
